/*-
 * Copyright (c) 2004 Michael Bushkov <bushman@rsu.ru>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

#ifndef __HOST_DEFS_H
#define __HOST_DEFS_H

#include <sys/types.h>
#include <netdb.h>

/* basic structure for *getby* request results */
struct host_result {
	struct		hostent ht_result;	/* the result itself */
	int		ht_error;		/* probable error */

	char		*ht_buffer;		/* buffer, where fields of ht_result point */
	size_t		ht_buffer_size;		/* buffer size */

	char		*ht_buffer_cursor;	/* current position in buffer - it's needed to send large buufers in parts */
};

/* basic structure for getaddrinfo request results */
struct addrinfo_result {
	struct addrinfo	*ai_result;	/* the first structure in the list of addrinfo structures */
	int 		ai_error;	/* probable error */
};

/* request data for getipnodebyname structure */
struct getipnodebyname_data {
	size_t	name_size;	/* name length */
	char	*name;		/* desired name */

	int 	af;		/* 'af' parameter for getipnodebyname function */
	int 	flags;		/* 'flags' parameter for getipnodebyname function */
};

/* request data for getipnodebyaddr structure */
struct getipnodebyaddr_data {
	size_t	src_size;	/* src length */
	char	*src;		/* src parameter of getipnodebyaddr */

	int	af;		/* af parameter of getipnodebyaddr */
	int	flags;		/* flags parameter of getipnodebyaddr */
};

/* request data for gethostbyname2 structure */
struct gethostbyname2_data {
	size_t	name_size;	/* name length */
	char	*name;		/* the name parameter of gethostbyname2 */

	int	af;		/* af parameter of gethostbyname2 */
};

/* request data for gethostbyaddr structure */
struct gethostbyaddr_data {
	int	addr_len;	/* addr array length */
	char	*addr;		/* addr parameter for gethostbyaddr */

	int	af;		/* af parameter for gethostbyaddr */
};

/* request data for getaddrinfo structure */
struct getaddrinfo_data {
	size_t		hostname_size;		/* hostname length */
	char		*hostname;		/* hostname parameter of getaddrinfo function */

	struct addrinfo	hint;			/* hint parameter of getaddrinfo function */
	struct addrinfo	*ai_cursor;		/* current addrinfo in the list - needed during sending */
};

#endif
